## Redirection

Batman wanted to redirect some endpoints to others. Robyn helped him do so by the following:

<Row>
  <Col>
  </Col>
  <Col sticky>
    <CodeGroup title="Request">

      ```python {{title: 'untyped'}}
      from robyn import Robyn, Response
      app = Robyn(__file__)

      @app.get("/")
      async def index():
        return Response(
          status_code=307,
          description="",
          headers={"Location": "landing"},
        )

      @app.get("/landing")
      def landing():
        return "hii!"
      ```
    </CodeGroup>
  </Col>
</Row>

---

## What's next?

Now, Batman wanted to have the ability to upload files to the server if any new villain appeared. Robyn introduced him to the file upload and some of the form data features. 

- [File Uploads](/documentation/en/api_reference/file-uploads)
